"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ToolWolframAlpha = void 0;
const tools_1 = require("langchain/tools");
const logWrapper_1 = require("../../../utils/logWrapper");
class ToolWolframAlpha {
    constructor() {
        this.description = {
            displayName: 'Wolfram|Alpha',
            name: 'toolWolframAlpha',
            icon: 'file:wolfram-alpha.svg',
            group: ['transform'],
            version: 1,
            description: "Connects to WolframAlpha's computational intelligence engine.",
            defaults: {
                name: 'Wolfram Alpha',
            },
            credentials: [
                {
                    name: 'wolframAlphaApi',
                    required: true,
                },
            ],
            codex: {
                categories: ['AI'],
                subcategories: {
                    AI: ['Tools'],
                },
                resources: {
                    primaryDocumentation: [
                        {
                            url: 'https://docs.n8n.io/integrations/builtin/cluster-nodes/sub-nodes/n8n-nodes-langchain.toolwolframalpha/',
                        },
                    ],
                },
            },
            inputs: [],
            outputs: ["ai_tool"],
            outputNames: ['Tool'],
            properties: [],
        };
    }
    async supplyData() {
        const credentials = await this.getCredentials('wolframAlphaApi');
        return {
            response: (0, logWrapper_1.logWrapper)(new tools_1.WolframAlphaTool({ appid: credentials.appId }), this),
        };
    }
}
exports.ToolWolframAlpha = ToolWolframAlpha;
//# sourceMappingURL=ToolWolframAlpha.node.js.map